@@ -248,7 +248,7 @@ class Provider:
                 return model
         return None
 
-    def extract_usage(self, response_data: Any, *, api_flavor: str | None = None) -> tuple[str | None, Usage]:
+    def extract_usage(self, response_data: Any, *, api_flavor: str = 'default') -> tuple[str | None, Usage]:
         """Extract model name and usage information from a response.
 
         Args:
@@ -264,17 +264,11 @@ class Provider:
         if self.extractors is None:
             raise ValueError('No extraction logic defined for this provider')
 
-        if api_flavor is None:
-            if len(self.extractors) == 1:
-                extractor = self.extractors[0]
-            else:
-                raise ValueError('No api_flavor specified and multiple extractors available')
-        else:
-            try:
-                extractor = next(e for e in self.extractors if e.api_flavor == api_flavor)
-            except StopIteration as e:
-                fs = ', '.join(e.api_flavor for e in self.extractors)
-                raise ValueError(f'Unknown api_flavor {api_flavor!r}, allowed values: {fs}') from e
+        try:
+            extractor = next(e for e in self.extractors if e.api_flavor == api_flavor)
+        except StopIteration as e:
+            fs = ', '.join(e.api_flavor for e in self.extractors)
+            raise ValueError(f'Unknown api_flavor {api_flavor!r}, allowed values: {fs}') from e
 
         return extractor.extract(response_data)
 
@@ -387,9 +381,12 @@ def _extract_path(
         error_path.append(step)
         if isinstance(step, ArrayMatch):
             if not _is_sequence(data):
-                raise ValueError(
-                    f'Expected `{_dot_path(data_path, error_path)}` value to be a sequence, got {_type_name(data)}'
-                )
+                if required:
+                    raise ValueError(
+                        f'Expected `{_dot_path(data_path, error_path)}` value to be a sequence, got {_type_name(data)}'
+                    )
+                else:
+                    return None
             if extracted_data := step.extract(data):
                 data = extracted_data
             elif required:
